Method: Net::SSH::Authentication::KeyManager#finish

Defined in:
lib/net/ssh/authentication/key_manager.rb

#finishObject

This is used as a hint to the KeyManager indicating that the agent connection is no longer needed. Any other open resources may be closed at this time.

Calling this does NOT indicate that the KeyManager will no longer be used. Identities may still be requested and operations done on loaded identities, in which case, the agent will be automatically reconnected. This method simply allows the client connection to be closed when it will not be used in the immediate future.



83
84
85
86
# File 'lib/net/ssh/authentication/key_manager.rb', line 83

def finish
  @agent.close if @agent
  @agent = nil
end